pub enum ParticipantEvent {
ChannelCreated(ConnectAddr),
ChannelDeleted(ConnectAddr),
}Expand description
A Participant can throw different events, you are obligated to carefully empty the queue from time to time.
Variants
ChannelCreated(ConnectAddr)
ChannelDeleted(ConnectAddr)